OptProblem: OptProblem object.

OptProblemR Documentation

OptProblem object.

Description

The OptProblem contains all the constants values which define a OptProblem within our MBO Steps. It is an environment and is always pointed at by the OptState.


mlrMBO documentation built on March 1, 2026, 9:07 a.m.